import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_th=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`th`,weekdays:`อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัสบดี_ศุกร์_เสาร์`.split(`_`),weekdaysShort:`อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัส_ศุกร์_เสาร์`.split(`_`),weekdaysMin:`อา._จ._อ._พ._พฤ._ศ._ส.`.split(`_`),months:`มกราคม_กุมภาพันธ์_มีนาคม_เมษายน_พฤษภาคม_มิถุนายน_กรกฎาคม_สิงหาคม_กันยายน_ตุลาคม_พฤศจิกายน_ธันวาคม`.split(`_`),monthsShort:`ม.ค._ก.พ._มี.ค._เม.ย._พ.ค._มิ.ย._ก.ค._ส.ค._ก.ย._ต.ค._พ.ย._ธ.ค.`.split(`_`),formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY เวลา H:mm`,LLLL:`วันddddที่ D MMMM YYYY เวลา H:mm`},relativeTime:{future:`อีก %s`,past:`%sที่แล้ว`,s:`ไม่กี่วินาที`,m:`1 นาที`,mm:`%d นาที`,h:`1 ชั่วโมง`,hh:`%d ชั่วโมง`,d:`1 วัน`,dd:`%d วัน`,M:`1 เดือน`,MM:`%d เดือน`,y:`1 ปี`,yy:`%d ปี`},ordinal:function(e){return e+`.`}};return n.default.locale(r,null,!0),r}))}));export default n();