import{vt as e}from"./mui-BgU4WrXF.js";import{t}from"./Skeleton-DLSq3aej.js";import{vt as n,xt as r}from"./index-bel1r0Sr.js";var i=e(),a=({columns:e,startAction:a,endAction:o,ref:s})=>[...[,,,]].map((c,l)=>(0,i.jsx)(n,{ref:l===0?s:null,children:[...Array(e)].map((n,s)=>{let c=a&&s===0||o&&s===e-1;return(0,i.jsx)(r,{padding:c?`none`:`normal`,children:!c&&(0,i.jsx)(t,{})},-s)})},-l));export{a as t};