import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_uk=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r=`січня_лютого_березня_квітня_травня_червня_липня_серпня_вересня_жовтня_листопада_грудня`.split(`_`),i=`січень_лютий_березень_квітень_травень_червень_липень_серпень_вересень_жовтень_листопад_грудень`.split(`_`),a=/D[oD]?(\[[^[\]]*\]|\s)+MMMM?/;function o(e,t,n){var r,i;return n===`m`?t?`хвилина`:`хвилину`:n===`h`?t?`година`:`годину`:e+` `+(r=+e,i={ss:t?`секунда_секунди_секунд`:`секунду_секунди_секунд`,mm:t?`хвилина_хвилини_хвилин`:`хвилину_хвилини_хвилин`,hh:t?`година_години_годин`:`годину_години_годин`,dd:`день_дні_днів`,MM:`місяць_місяці_місяців`,yy:`рік_роки_років`}[n].split(`_`),r%10==1&&r%100!=11?i[0]:r%10>=2&&r%10<=4&&(r%100<10||r%100>=20)?i[1]:i[2])}var s=function(e,t){return a.test(t)?r[e.month()]:i[e.month()]};s.s=i,s.f=r;var c={name:`uk`,weekdays:`неділя_понеділок_вівторок_середа_четвер_п’ятниця_субота`.split(`_`),weekdaysShort:`ндл_пнд_втр_срд_чтв_птн_сбт`.split(`_`),weekdaysMin:`нд_пн_вт_ср_чт_пт_сб`.split(`_`),months:s,monthsShort:`січ_лют_бер_квіт_трав_черв_лип_серп_вер_жовт_лист_груд`.split(`_`),weekStart:1,relativeTime:{future:`за %s`,past:`%s тому`,s:`декілька секунд`,m:o,mm:o,h:o,hh:o,d:`день`,dd:o,M:`місяць`,MM:o,y:`рік`,yy:o},ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD.MM.YYYY`,LL:`D MMMM YYYY р.`,LLL:`D MMMM YYYY р., HH:mm`,LLLL:`dddd, D MMMM YYYY р., HH:mm`}};return n.default.locale(c,null,!0),c}))}));export default n();