import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_pl=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e);function r(e){return e%10<5&&e%10>1&&~~(e/10)%10!=1}function i(e,t,n){var i=e+` `;switch(n){case`m`:return t?`minuta`:`minutę`;case`mm`:return i+(r(e)?`minuty`:`minut`);case`h`:return t?`godzina`:`godzinę`;case`hh`:return i+(r(e)?`godziny`:`godzin`);case`MM`:return i+(r(e)?`miesiące`:`miesięcy`);case`yy`:return i+(r(e)?`lata`:`lat`)}}var a=`stycznia_lutego_marca_kwietnia_maja_czerwca_lipca_sierpnia_września_października_listopada_grudnia`.split(`_`),o=`styczeń_luty_marzec_kwiecień_maj_czerwiec_lipiec_sierpień_wrzesień_październik_listopad_grudzień`.split(`_`),s=/D MMMM/,c=function(e,t){return s.test(t)?a[e.month()]:o[e.month()]};c.s=o,c.f=a;var l={name:`pl`,weekdays:`niedziela_poniedziałek_wtorek_środa_czwartek_piątek_sobota`.split(`_`),weekdaysShort:`ndz_pon_wt_śr_czw_pt_sob`.split(`_`),weekdaysMin:`Nd_Pn_Wt_Śr_Cz_Pt_So`.split(`_`),months:c,monthsShort:`sty_lut_mar_kwi_maj_cze_lip_sie_wrz_paź_lis_gru`.split(`_`),ordinal:function(e){return e+`.`},weekStart:1,yearStart:4,relativeTime:{future:`za %s`,past:`%s temu`,s:`kilka sekund`,m:i,mm:i,h:i,hh:i,d:`1 dzień`,dd:`%d dni`,M:`miesiąc`,MM:i,y:`rok`,yy:i},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD.MM.YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`dddd, D MMMM YYYY HH:mm`}};return n.default.locale(l,null,!0),l}))}));export default n();