import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_he=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={s:`מספר שניות`,ss:`%d שניות`,m:`דקה`,mm:`%d דקות`,h:`שעה`,hh:`%d שעות`,hh2:`שעתיים`,d:`יום`,dd:`%d ימים`,dd2:`יומיים`,M:`חודש`,MM:`%d חודשים`,MM2:`חודשיים`,y:`שנה`,yy:`%d שנים`,yy2:`שנתיים`};function i(e,t,n){return(r[n+(e===2?`2`:``)]||r[n]).replace(`%d`,e)}var a={name:`he`,weekdays:`ראשון_שני_שלישי_רביעי_חמישי_שישי_שבת`.split(`_`),weekdaysShort:`א׳_ב׳_ג׳_ד׳_ה׳_ו׳_ש׳`.split(`_`),weekdaysMin:`א׳_ב׳_ג׳_ד׳_ה׳_ו_ש׳`.split(`_`),months:`ינואר_פברואר_מרץ_אפריל_מאי_יוני_יולי_אוגוסט_ספטמבר_אוקטובר_נובמבר_דצמבר`.split(`_`),monthsShort:`ינו_פבר_מרץ_אפר_מאי_יונ_יול_אוג_ספט_אוק_נוב_דצמ`.split(`_`),relativeTime:{future:`בעוד %s`,past:`לפני %s`,s:i,m:i,mm:i,h:i,hh:i,d:i,dd:i,M:i,MM:i,y:i,yy:i},ordinal:function(e){return e},format:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D [ב]MMMM YYYY`,LLL:`D [ב]MMMM YYYY HH:mm`,LLLL:`dddd, D [ב]MMMM YYYY HH:mm`,l:`D/M/YYYY`,ll:`D MMM YYYY`,lll:`D MMM YYYY HH:mm`,llll:`ddd, D MMM YYYY HH:mm`},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D [ב]MMMM YYYY`,LLL:`D [ב]MMMM YYYY HH:mm`,LLLL:`dddd, D [ב]MMMM YYYY HH:mm`,l:`D/M/YYYY`,ll:`D MMM YYYY`,lll:`D MMM YYYY HH:mm`,llll:`ddd, D MMM YYYY HH:mm`}};return n.default.locale(a,null,!0),a}))}));export default n();