import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_gl=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`gl`,weekdays:`domingo_luns_martes_mércores_xoves_venres_sábado`.split(`_`),months:`xaneiro_febreiro_marzo_abril_maio_xuño_xullo_agosto_setembro_outubro_novembro_decembro`.split(`_`),weekStart:1,weekdaysShort:`dom._lun._mar._mér._xov._ven._sáb.`.split(`_`),monthsShort:`xan._feb._mar._abr._mai._xuñ._xul._ago._set._out._nov._dec.`.split(`_`),weekdaysMin:`do_lu_ma_mé_xo_ve_sá`.split(`_`),ordinal:function(e){return e+`º`},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD/MM/YYYY`,LL:`D [de] MMMM [de] YYYY`,LLL:`D [de] MMMM [de] YYYY H:mm`,LLLL:`dddd, D [de] MMMM [de] YYYY H:mm`},relativeTime:{future:`en %s`,past:`fai %s`,s:`uns segundos`,m:`un minuto`,mm:`%d minutos`,h:`unha hora`,hh:`%d horas`,d:`un día`,dd:`%d días`,M:`un mes`,MM:`%d meses`,y:`un ano`,yy:`%d anos`}};return n.default.locale(r,null,!0),r}))}));export default n();