import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_vi=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`vi`,weekdays:`chủ nhật_thứ hai_thứ ba_thứ tư_thứ năm_thứ sáu_thứ bảy`.split(`_`),months:`tháng 1_tháng 2_tháng 3_tháng 4_tháng 5_tháng 6_tháng 7_tháng 8_tháng 9_tháng 10_tháng 11_tháng 12`.split(`_`),weekStart:1,weekdaysShort:`CN_T2_T3_T4_T5_T6_T7`.split(`_`),monthsShort:`Th01_Th02_Th03_Th04_Th05_Th06_Th07_Th08_Th09_Th10_Th11_Th12`.split(`_`),weekdaysMin:`CN_T2_T3_T4_T5_T6_T7`.split(`_`),ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM [năm] YYYY`,LLL:`D MMMM [năm] YYYY HH:mm`,LLLL:`dddd, D MMMM [năm] YYYY HH:mm`,l:`DD/M/YYYY`,ll:`D MMM YYYY`,lll:`D MMM YYYY HH:mm`,llll:`ddd, D MMM YYYY HH:mm`},relativeTime:{future:`%s tới`,past:`%s trước`,s:`vài giây`,m:`một phút`,mm:`%d phút`,h:`một giờ`,hh:`%d giờ`,d:`một ngày`,dd:`%d ngày`,M:`một tháng`,MM:`%d tháng`,y:`một năm`,yy:`%d năm`}};return n.default.locale(r,null,!0),r}))}));export default n();