import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_pt_br=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`pt-br`,weekdays:`domingo_segunda-feira_terça-feira_quarta-feira_quinta-feira_sexta-feira_sábado`.split(`_`),weekdaysShort:`dom_seg_ter_qua_qui_sex_sáb`.split(`_`),weekdaysMin:`Do_2ª_3ª_4ª_5ª_6ª_Sá`.split(`_`),months:`janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro`.split(`_`),monthsShort:`jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez`.split(`_`),ordinal:function(e){return e+`º`},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D [de] MMMM [de] YYYY`,LLL:`D [de] MMMM [de] YYYY [às] HH:mm`,LLLL:`dddd, D [de] MMMM [de] YYYY [às] HH:mm`},relativeTime:{future:`em %s`,past:`há %s`,s:`poucos segundos`,m:`um minuto`,mm:`%d minutos`,h:`uma hora`,hh:`%d horas`,d:`um dia`,dd:`%d dias`,M:`um mês`,MM:`%d meses`,y:`um ano`,yy:`%d anos`}};return n.default.locale(r,null,!0),r}))}));export default n();