import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_hu=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`hu`,weekdays:`vasárnap_hétfő_kedd_szerda_csütörtök_péntek_szombat`.split(`_`),weekdaysShort:`vas_hét_kedd_sze_csüt_pén_szo`.split(`_`),weekdaysMin:`v_h_k_sze_cs_p_szo`.split(`_`),months:`január_február_március_április_május_június_július_augusztus_szeptember_október_november_december`.split(`_`),monthsShort:`jan_feb_márc_ápr_máj_jún_júl_aug_szept_okt_nov_dec`.split(`_`),ordinal:function(e){return e+`.`},weekStart:1,relativeTime:{future:`%s múlva`,past:`%s`,s:function(e,t,n,r){return`néhány másodperc`+(r||t?``:`e`)},m:function(e,t,n,r){return`egy perc`+(r||t?``:`e`)},mm:function(e,t,n,r){return e+` perc`+(r||t?``:`e`)},h:function(e,t,n,r){return`egy `+(r||t?`óra`:`órája`)},hh:function(e,t,n,r){return e+` `+(r||t?`óra`:`órája`)},d:function(e,t,n,r){return`egy `+(r||t?`nap`:`napja`)},dd:function(e,t,n,r){return e+` `+(r||t?`nap`:`napja`)},M:function(e,t,n,r){return`egy `+(r||t?`hónap`:`hónapja`)},MM:function(e,t,n,r){return e+` `+(r||t?`hónap`:`hónapja`)},y:function(e,t,n,r){return`egy `+(r||t?`év`:`éve`)},yy:function(e,t,n,r){return e+` `+(r||t?`év`:`éve`)}},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`YYYY.MM.DD.`,LL:`YYYY. MMMM D.`,LLL:`YYYY. MMMM D. H:mm`,LLLL:`YYYY. MMMM D., dddd H:mm`}};return n.default.locale(r,null,!0),r}))}));export default n();