import{i as e}from"./chunk-aKtaBQYM.js";import{Ft as t,H as n,R as r,V as i,Y as a,at as o,dt as s,lt as c,mt as l,ot as u,rt as d,vt as f}from"./mui-BgU4WrXF.js";import{Yt as p}from"./index-bel1r0Sr.js";var m=d();function h({props:e,name:t,defaultTheme:n,themeId:r}){let i=c(n);return r&&(i=i[r]||i),p({theme:i,name:t,props:e})}var g=e(t(),1),_=f(),v=s(),y=m(`div`,{name:`MuiContainer`,slot:`Root`,overridesResolver:(e,t)=>{let{ownerState:n}=e;return[t.root,t[`maxWidth${l(String(n.maxWidth))}`],n.fixed&&t.fixed,n.disableGutters&&t.disableGutters]}}),b=e=>h({props:e,name:`MuiContainer`,defaultTheme:v}),x=(e,t)=>{let n=e=>o(t,e),{classes:r,fixed:i,disableGutters:s,maxWidth:c}=e;return a({root:[`root`,c&&`maxWidth${l(String(c))}`,i&&`fixed`,s&&`disableGutters`]},n,r)};function S(e={}){let{createStyledComponent:t=y,useThemeProps:n=b,componentName:r=`MuiContainer`}=e,i=t(({theme:e,ownerState:t})=>({width:`100%`,marginLeft:`auto`,boxSizing:`border-box`,marginRight:`auto`,...!t.disableGutters&&{paddingLeft:e.spacing(2),paddingRight:e.spacing(2),[e.breakpoints.up(`sm`)]:{paddingLeft:e.spacing(3),paddingRight:e.spacing(3)}}}),({theme:e,ownerState:t})=>t.fixed&&Object.keys(e.breakpoints.values).reduce((t,n)=>{let r=n,i=e.breakpoints.values[r];return i!==0&&(t[e.breakpoints.up(r)]={maxWidth:`${i}${e.breakpoints.unit}`}),t},{}),({theme:e,ownerState:t})=>({...t.maxWidth===`xs`&&{[e.breakpoints.up(`xs`)]:{maxWidth:Math.max(e.breakpoints.values.xs,444)}},...t.maxWidth&&t.maxWidth!==`xs`&&{[e.breakpoints.up(t.maxWidth)]:{maxWidth:`${e.breakpoints.values[t.maxWidth]}${e.breakpoints.unit}`}}}));return g.forwardRef(function(e,t){let a=n(e),{className:o,component:s=`div`,disableGutters:c=!1,fixed:l=!1,maxWidth:d=`lg`,classes:f,...p}=a,m={...a,component:s,disableGutters:c,fixed:l,maxWidth:d};return(0,_.jsx)(i,{as:s,ownerState:m,className:u(x(m,r).root,o),ref:t,...p})})}var C=S({createStyledComponent:n(`div`,{name:`MuiContainer`,slot:`Root`,overridesResolver:(e,t)=>{let{ownerState:n}=e;return[t.root,t[`maxWidth${i(String(n.maxWidth))}`],n.fixed&&t.fixed,n.disableGutters&&t.disableGutters]}}),useThemeProps:e=>r({props:e,name:`MuiContainer`})});export{h as n,m as r,C as t};