import{i as e}from"./chunk-aKtaBQYM.js";import{Ft as t,H as n,R as r,Y as i,at as a,it as o,ot as s,vt as c}from"./mui-BgU4WrXF.js";import{Ct as l}from"./index-bel1r0Sr.js";var u=e(t(),1);function d(e){return a(`MuiTableHead`,e)}o(`MuiTableHead`,[`root`]);var f=c(),p=e=>{let{classes:t}=e;return i({root:[`root`]},d,t)},m=n(`thead`,{name:`MuiTableHead`,slot:`Root`})({display:`table-header-group`}),h={variant:`head`},g=`thead`,_=u.forwardRef(function(e,t){let n=r({props:e,name:`MuiTableHead`}),{className:i,component:a=g,...o}=n,c={...n,component:a},u=p(c);return(0,f.jsx)(l.Provider,{value:h,children:(0,f.jsx)(m,{as:a,className:s(u.root,i),ref:t,role:a===g?null:`rowgroup`,ownerState:c,...o})})});export{_ as t};