import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_sr=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={words:{m:[`jedan minut`,`jednog minuta`],mm:[`%d minut`,`%d minuta`,`%d minuta`],h:[`jedan sat`,`jednog sata`],hh:[`%d sat`,`%d sata`,`%d sati`],d:[`jedan dan`,`jednog dana`],dd:[`%d dan`,`%d dana`,`%d dana`],M:[`jedan mesec`,`jednog meseca`],MM:[`%d mesec`,`%d meseca`,`%d meseci`],y:[`jednu godinu`,`jedne godine`],yy:[`%d godinu`,`%d godine`,`%d godina`]},correctGrammarCase:function(e,t){return e%10>=1&&e%10<=4&&(e%100<10||e%100>=20)?e%10==1?t[0]:t[1]:t[2]},relativeTimeFormatter:function(e,t,n,i){var a=r.words[n];if(n.length===1)return n===`y`&&t?`jedna godina`:i||t?a[0]:a[1];var o=r.correctGrammarCase(e,a);return n===`yy`&&t&&o===`%d godinu`?e+` godina`:o.replace(`%d`,e)}},i={name:`sr`,weekdays:`Nedelja_Ponedeljak_Utorak_Sreda_Četvrtak_Petak_Subota`.split(`_`),weekdaysShort:`Ned._Pon._Uto._Sre._Čet._Pet._Sub.`.split(`_`),weekdaysMin:`ne_po_ut_sr_če_pe_su`.split(`_`),months:`Januar_Februar_Mart_April_Maj_Jun_Jul_Avgust_Septembar_Oktobar_Novembar_Decembar`.split(`_`),monthsShort:`Jan._Feb._Mar._Apr._Maj_Jun_Jul_Avg._Sep._Okt._Nov._Dec.`.split(`_`),weekStart:1,relativeTime:{future:`za %s`,past:`pre %s`,s:`nekoliko sekundi`,m:r.relativeTimeFormatter,mm:r.relativeTimeFormatter,h:r.relativeTimeFormatter,hh:r.relativeTimeFormatter,d:r.relativeTimeFormatter,dd:r.relativeTimeFormatter,M:r.relativeTimeFormatter,MM:r.relativeTimeFormatter,y:r.relativeTimeFormatter,yy:r.relativeTimeFormatter},ordinal:function(e){return e+`.`},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`D. M. YYYY.`,LL:`D. MMMM YYYY.`,LLL:`D. MMMM YYYY. H:mm`,LLLL:`dddd, D. MMMM YYYY. H:mm`}};return n.default.locale(i,null,!0),i}))}));export default n();