import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_sv=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`sv`,weekdays:`söndag_måndag_tisdag_onsdag_torsdag_fredag_lördag`.split(`_`),weekdaysShort:`sön_mån_tis_ons_tor_fre_lör`.split(`_`),weekdaysMin:`sö_må_ti_on_to_fr_lö`.split(`_`),months:`januari_februari_mars_april_maj_juni_juli_augusti_september_oktober_november_december`.split(`_`),monthsShort:`jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec`.split(`_`),weekStart:1,yearStart:4,ordinal:function(e){var t=e%10;return`[`+e+(t===1||t===2?`a`:`e`)+`]`},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`YYYY-MM-DD`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY [kl.] HH:mm`,LLLL:`dddd D MMMM YYYY [kl.] HH:mm`,lll:`D MMM YYYY HH:mm`,llll:`ddd D MMM YYYY HH:mm`},relativeTime:{future:`om %s`,past:`för %s sedan`,s:`några sekunder`,m:`en minut`,mm:`%d minuter`,h:`en timme`,hh:`%d timmar`,d:`en dag`,dd:`%d dagar`,M:`en månad`,MM:`%d månader`,y:`ett år`,yy:`%d år`}};return n.default.locale(r,null,!0),r}))}));export default n();