import{i as e}from"./chunk-aKtaBQYM.js";import{Ft as t}from"./mui-BgU4WrXF.js";var n=e(t(),1),r=e=>(0,n.useMemo)(()=>({language:{name:e(`loginLanguage`),type:`string`},mapGeofences:{name:e(`attributeShowGeofences`),type:`boolean`},mapLiveRoutes:{name:e(`mapLiveRoutes`),type:`string`},mapDirection:{name:e(`mapDirection`),type:`string`},mapFollow:{name:e(`deviceFollow`),type:`boolean`},mapCluster:{name:e(`mapClustering`),type:`boolean`},mapOnSelect:{name:e(`mapOnSelect`),type:`boolean`},activeMapStyles:{name:e(`mapActive`),type:`string`},devicePrimary:{name:e(`devicePrimaryInfo`),type:`string`},deviceSecondary:{name:e(`deviceSecondaryInfo`),type:`string`},soundEvents:{name:e(`eventsSoundEvents`),type:`string`},soundAlarms:{name:e(`eventsSoundAlarms`),type:`string`},positionItems:{name:e(`attributePopupInfo`),type:`string`},googleKey:{name:e(`mapGoogleKey`),type:`string`},locationIqKey:{name:e(`mapLocationIqKey`),type:`string`},mapboxAccessToken:{name:e(`mapMapboxKey`),type:`string`},mapTilerKey:{name:e(`mapMapTilerKey`),type:`string`},bingMapsKey:{name:e(`mapBingKey`),type:`string`},openWeatherKey:{name:e(`mapOpenWeatherKey`),type:`string`},tomTomKey:{name:e(`mapTomTomKey`),type:`string`},hereKey:{name:e(`mapHereKey`),type:`string`},notificationTokens:{name:e(`attributeNotificationTokens`),type:`string`},"ui.disableSavedCommands":{name:e(`attributeUiDisableSavedCommands`),type:`boolean`},"ui.disableGroups":{name:e(`attributeUiDisableGroups`),type:`boolean`},"ui.disableAttributes":{name:e(`attributeUiDisableAttributes`),type:`boolean`},"ui.disableEvents":{name:e(`attributeUiDisableEvents`),type:`boolean`},"ui.disableVehicleFeatures":{name:e(`attributeUiDisableVehicleFeatures`),type:`boolean`},"ui.disableDrivers":{name:e(`attributeUiDisableDrivers`),type:`boolean`},"ui.disableComputedAttributes":{name:e(`attributeUiDisableComputedAttributes`),type:`boolean`},"ui.disableCalendars":{name:e(`attributeUiDisableCalendars`),type:`boolean`},"ui.disableMaintenance":{name:e(`attributeUiDisableMaintenance`),type:`boolean`},"web.liveRouteLength":{name:e(`attributeWebLiveRouteLength`),type:`number`},mapLineWidth:{name:e(`attributeMapLineWidth`),type:`number`},mapLineOpacity:{name:e(`attributeMapLineOpacity`),type:`number`},"web.selectZoom":{name:e(`attributeWebSelectZoom`),type:`number`},"web.maxZoom":{name:e(`attributeWebMaxZoom`),type:`number`},iconScale:{name:e(`sharedIconScale`),type:`number`},navigationAppLink:{name:e(`attributeNavigationAppLink`),type:`string`},navigationAppTitle:{name:e(`attributeNavigationAppTitle`),type:`string`}}),[e]);export{r as t};