import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_uz=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`uz`,weekdays:`Якшанба_Душанба_Сешанба_Чоршанба_Пайшанба_Жума_Шанба`.split(`_`),months:`январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр`.split(`_`),weekStart:1,weekdaysShort:`Якш_Душ_Сеш_Чор_Пай_Жум_Шан`.split(`_`),monthsShort:`янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек`.split(`_`),weekdaysMin:`Як_Ду_Се_Чо_Па_Жу_Ша`.split(`_`),ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`D MMMM YYYY, dddd HH:mm`},relativeTime:{future:`Якин %s ичида`,past:`%s олдин`,s:`фурсат`,m:`бир дакика`,mm:`%d дакика`,h:`бир соат`,hh:`%d соат`,d:`бир кун`,dd:`%d кун`,M:`бир ой`,MM:`%d ой`,y:`бир йил`,yy:`%d йил`}};return n.default.locale(r,null,!0),r}))}));export default n();