import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_ca=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`ca`,weekdays:`Diumenge_Dilluns_Dimarts_Dimecres_Dijous_Divendres_Dissabte`.split(`_`),weekdaysShort:`Dg._Dl._Dt._Dc._Dj._Dv._Ds.`.split(`_`),weekdaysMin:`Dg_Dl_Dt_Dc_Dj_Dv_Ds`.split(`_`),months:`Gener_Febrer_Març_Abril_Maig_Juny_Juliol_Agost_Setembre_Octubre_Novembre_Desembre`.split(`_`),monthsShort:`Gen._Febr._Març_Abr._Maig_Juny_Jul._Ag._Set._Oct._Nov._Des.`.split(`_`),weekStart:1,formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM [de] YYYY`,LLL:`D MMMM [de] YYYY [a les] H:mm`,LLLL:`dddd D MMMM [de] YYYY [a les] H:mm`,ll:`D MMM YYYY`,lll:`D MMM YYYY, H:mm`,llll:`ddd D MMM YYYY, H:mm`},relativeTime:{future:`d'aquí %s`,past:`fa %s`,s:`uns segons`,m:`un minut`,mm:`%d minuts`,h:`una hora`,hh:`%d hores`,d:`un dia`,dd:`%d dies`,M:`un mes`,MM:`%d mesos`,y:`un any`,yy:`%d anys`},ordinal:function(e){return``+e+(e===1||e===3?`r`:e===2?`n`:e===4?`t`:`è`)}};return n.default.locale(r,null,!0),r}))}));export default n();