import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_sk=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e);function r(e){return e>1&&e<5&&~~(e/10)!=1}function i(e,t,n,i){var a=e+` `;switch(n){case`s`:return t||i?`pár sekúnd`:`pár sekundami`;case`m`:return t?`minúta`:i?`minútu`:`minútou`;case`mm`:return t||i?a+(r(e)?`minúty`:`minút`):a+`minútami`;case`h`:return t?`hodina`:i?`hodinu`:`hodinou`;case`hh`:return t||i?a+(r(e)?`hodiny`:`hodín`):a+`hodinami`;case`d`:return t||i?`deň`:`dňom`;case`dd`:return t||i?a+(r(e)?`dni`:`dní`):a+`dňami`;case`M`:return t||i?`mesiac`:`mesiacom`;case`MM`:return t||i?a+(r(e)?`mesiace`:`mesiacov`):a+`mesiacmi`;case`y`:return t||i?`rok`:`rokom`;case`yy`:return t||i?a+(r(e)?`roky`:`rokov`):a+`rokmi`}}var a={name:`sk`,weekdays:`nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota`.split(`_`),weekdaysShort:`ne_po_ut_st_št_pi_so`.split(`_`),weekdaysMin:`ne_po_ut_st_št_pi_so`.split(`_`),months:`január_február_marec_apríl_máj_jún_júl_august_september_október_november_december`.split(`_`),monthsShort:`jan_feb_mar_apr_máj_jún_júl_aug_sep_okt_nov_dec`.split(`_`),weekStart:1,yearStart:4,ordinal:function(e){return e+`.`},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD.MM.YYYY`,LL:`D. MMMM YYYY`,LLL:`D. MMMM YYYY H:mm`,LLLL:`dddd D. MMMM YYYY H:mm`,l:`D. M. YYYY`},relativeTime:{future:`za %s`,past:`pred %s`,s:i,m:i,mm:i,h:i,hh:i,d:i,dd:i,M:i,MM:i,y:i,yy:i}};return n.default.locale(a,null,!0),a}))}));export default n();