import{i as e}from"./chunk-aKtaBQYM.js";import{Ft as t,vt as n}from"./mui-BgU4WrXF.js";import{i as r,n as i,r as a,t as o}from"./ExpandMore-D0ycvrdR.js";import{t as s}from"./Typography-7EcQ2i3p.js";import{t as c}from"./TextField-DctlzLY-.js";import{pt as l}from"./index-bel1r0Sr.js";import{n as u,t as d}from"./useSettingsStyles-Bugi6oTj.js";import{t as f}from"./EditItemView-BPUZddYO.js";import{t as p}from"./BaseCommandView-7Yk4HVG-.js";var m=e(t(),1),h=n(),g=()=>{let{classes:e}=d(),t=l(),[n,g]=(0,m.useState)();return(0,h.jsx)(f,{endpoint:`commands`,item:n,setItem:g,validate:()=>n&&n.type,menu:(0,h.jsx)(u,{}),breadcrumbs:[`settingsTitle`,`sharedSavedCommand`],children:n&&(0,h.jsxs)(r,{defaultExpanded:!0,children:[(0,h.jsx)(i,{expandIcon:(0,h.jsx)(o,{}),children:(0,h.jsx)(s,{variant:`subtitle1`,children:t(`sharedRequired`)})}),(0,h.jsxs)(a,{className:e.details,children:[(0,h.jsx)(c,{value:n.description||``,onChange:e=>g({...n,description:e.target.value}),label:t(`sharedDescription`)}),(0,h.jsx)(p,{item:n,setItem:g})]})]})})};export{g as default};