import{i as e}from"./chunk-aKtaBQYM.js";import{C as t,Ft as n,H as r,R as i,V as a,Y as o,at as s,it as c,ot as l,vt as u,z as d}from"./mui-BgU4WrXF.js";var f=e(n(),1);function p(e){return s(`MuiTypography`,e)}var m=c(`MuiTypography`,[`root`,`h1`,`h2`,`h3`,`h4`,`h5`,`h6`,`subtitle1`,`subtitle2`,`body1`,`body2`,`inherit`,`button`,`caption`,`overline`,`alignLeft`,`alignRight`,`alignCenter`,`alignJustify`,`noWrap`,`gutterBottom`]),h=u(),g=e=>{let{align:t,gutterBottom:n,noWrap:r,variant:i,classes:s}=e;return o({root:[`root`,i,e.align!==`inherit`&&`align${a(t)}`,n&&`gutterBottom`,r&&`noWrap`]},p,s)},_=r(`span`,{name:`MuiTypography`,slot:`Root`,overridesResolver:(e,t)=>{let{ownerState:n}=e;return[t.root,n.variant&&t[n.variant],n.align!==`inherit`&&t[`align${a(n.align)}`],n.noWrap&&t.noWrap,n.gutterBottom&&t.gutterBottom]}})(d(({theme:e})=>({margin:0,variants:[{props:{variant:`inherit`},style:{font:`inherit`,lineHeight:`inherit`,letterSpacing:`inherit`}},...Object.entries(e.typography).filter(([e,t])=>e!==`inherit`&&t&&typeof t==`object`).map(([e,t])=>({props:{variant:e},style:t})),...Object.entries(e.palette).filter(t()).map(([t])=>({props:{color:t},style:{color:(e.vars||e).palette[t].main}})),...Object.entries(e.palette?.text||{}).filter(([,e])=>typeof e==`string`).map(([t])=>({props:{color:`text${a(t)}`},style:{color:(e.vars||e).palette.text[t]}})),{props:({ownerState:e})=>e.align!==`inherit`,style:{textAlign:`var(--Typography-textAlign)`}},{props:({ownerState:e})=>e.noWrap,style:{overflow:`hidden`,textOverflow:`ellipsis`,whiteSpace:`nowrap`}},{props:({ownerState:e})=>e.gutterBottom,style:{marginBottom:`0.35em`}}]}))),v={h1:`h1`,h2:`h2`,h3:`h3`,h4:`h4`,h5:`h5`,h6:`h6`,subtitle1:`h6`,subtitle2:`h6`,body1:`p`,body2:`p`,inherit:`p`},y=f.forwardRef(function(e,t){let n=i({props:e,name:`MuiTypography`}),{color:r,align:a=`inherit`,className:o,component:s,gutterBottom:c=!1,noWrap:u=!1,variant:d=`body1`,variantMapping:f=v,...p}=n,m={...n,align:a,color:r,className:o,component:s,gutterBottom:c,noWrap:u,variant:d,variantMapping:f};return(0,h.jsx)(_,{as:s||f[d]||v[d]||`span`,ref:t,className:l(g(m).root,o),...p,ownerState:m,style:{...a!==`inherit`&&{"--Typography-textAlign":a},...p.style}})});export{m as n,y as t};