import{t as e,vt as t}from"./mui-BgU4WrXF.js";var n=t(),r=e()(e=>({handle:{height:e.spacing(1),cursor:`ns-resize`,backgroundColor:e.palette.divider,flexShrink:0}})),i=()=>{let{classes:e}=r();return(0,n.jsx)(`div`,{className:e.handle,onPointerDown:e=>{e.preventDefault();let t=e.currentTarget.parentElement.getBoundingClientRect(),n=e=>{let n=e.clientY-t.top,r=Math.max(10,Math.min(90,n/t.height*100));document.documentElement.style.setProperty(`--report-map-height`,`${r}%`)},r=()=>{window.removeEventListener(`pointermove`,n),window.removeEventListener(`pointerup`,r)};window.addEventListener(`pointermove`,n),window.addEventListener(`pointerup`,r)}})};export{i as t};