import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_nl=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`nl`,weekdays:`zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag`.split(`_`),weekdaysShort:`zo._ma._di._wo._do._vr._za.`.split(`_`),weekdaysMin:`zo_ma_di_wo_do_vr_za`.split(`_`),months:`januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december`.split(`_`),monthsShort:`jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec`.split(`_`),ordinal:function(e){return`[`+e+(e===1||e===8||e>=20?`ste`:`de`)+`]`},weekStart:1,yearStart:4,formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD-MM-YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`dddd D MMMM YYYY HH:mm`},relativeTime:{future:`over %s`,past:`%s geleden`,s:`een paar seconden`,m:`een minuut`,mm:`%d minuten`,h:`een uur`,hh:`%d uur`,d:`een dag`,dd:`%d dagen`,M:`een maand`,MM:`%d maanden`,y:`een jaar`,yy:`%d jaar`}};return n.default.locale(r,null,!0),r}))}));export default n();