import{i as e}from"./chunk-aKtaBQYM.js";import{Ft as t}from"./mui-BgU4WrXF.js";var n=e(t(),1),r=e=>(0,n.useMemo)(()=>({speedLimit:{name:e(`attributeSpeedLimit`),type:`number`,dataType:`speed`},proximityEnterDistance:{name:e(`attributeProximityEnterDistance`),type:`number`,dataType:`distance`},proximityExitDistance:{name:e(`attributeProximityExitDistance`),type:`number`,dataType:`distance`},unaccompaniedDistance:{name:e(`attributeUnaccompaniedDistance`),type:`number`,dataType:`distance`},fuelDropThreshold:{name:e(`attributeFuelDropThreshold`),type:`number`},fuelIncreaseThreshold:{name:e(`attributeFuelIncreaseThreshold`),type:`number`},"report.ignoreOdometer":{name:e(`attributeReportIgnoreOdometer`),type:`boolean`},deviceInactivityStart:{name:e(`attributeDeviceInactivityStart`),type:`number`},deviceInactivityPeriod:{name:e(`attributeDeviceInactivityPeriod`),type:`number`},notificationTokens:{name:e(`attributeNotificationTokens`),type:`string`},"filter.invalid":{name:e(`attributeFilterInvalid`),type:`boolean`},"filter.zero":{name:e(`attributeFilterZero`),type:`boolean`},"filter.duplicate":{name:e(`attributeFilterDuplicate`),type:`boolean`},"filter.outdated":{name:e(`attributeFilterOutdated`),type:`boolean`},"filter.future":{name:e(`attributeFilterFuture`),type:`number`},"filter.past":{name:e(`attributeFilterPast`),type:`number`},"filter.accuracy":{name:e(`attributeFilterAccuracy`),type:`number`},"filter.approximate":{name:e(`attributeFilterApproximate`),type:`boolean`},"filter.static":{name:e(`attributeFilterStatic`),type:`boolean`},"filter.distance":{name:e(`attributeFilterDistance`),type:`number`},"filter.maxSpeed":{name:e(`attributeFilterMaxSpeed`),type:`number`},"filter.minPeriod":{name:e(`attributeFilterMinPeriod`),type:`number`},"filter.dailyLimit":{name:e(`attributeFilterDailyLimit`),type:`number`},"filter.dailyLimitInterval":{name:e(`attributeFilterDailyLimitInterval`),type:`number`},"filter.skipLimit":{name:e(`attributeFilterSkipLimit`),type:`number`},"filter.skipAttributes.enable":{name:e(`attributeFilterSkipAttributesEnable`),type:`boolean`},"filter.skipAttributes":{name:e(`attributeFilterSkipAttributes`),type:`string`},"time.override":{name:e(`attributeTimeOverride`),type:`string`}}),[e]);export{r as t};