import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_cs=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e);function r(e){return e>1&&e<5&&~~(e/10)!=1}function i(e,t,n,i){var a=e+` `;switch(n){case`s`:return t||i?`pár sekund`:`pár sekundami`;case`m`:return t?`minuta`:i?`minutu`:`minutou`;case`mm`:return t||i?a+(r(e)?`minuty`:`minut`):a+`minutami`;case`h`:return t?`hodina`:i?`hodinu`:`hodinou`;case`hh`:return t||i?a+(r(e)?`hodiny`:`hodin`):a+`hodinami`;case`d`:return t||i?`den`:`dnem`;case`dd`:return t||i?a+(r(e)?`dny`:`dní`):a+`dny`;case`M`:return t||i?`měsíc`:`měsícem`;case`MM`:return t||i?a+(r(e)?`měsíce`:`měsíců`):a+`měsíci`;case`y`:return t||i?`rok`:`rokem`;case`yy`:return t||i?a+(r(e)?`roky`:`let`):a+`lety`}}var a={name:`cs`,weekdays:`neděle_pondělí_úterý_středa_čtvrtek_pátek_sobota`.split(`_`),weekdaysShort:`ne_po_út_st_čt_pá_so`.split(`_`),weekdaysMin:`ne_po_út_st_čt_pá_so`.split(`_`),months:`leden_únor_březen_duben_květen_červen_červenec_srpen_září_říjen_listopad_prosinec`.split(`_`),monthsShort:`led_úno_bře_dub_kvě_čvn_čvc_srp_zář_říj_lis_pro`.split(`_`),weekStart:1,yearStart:4,ordinal:function(e){return e+`.`},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD.MM.YYYY`,LL:`D. MMMM YYYY`,LLL:`D. MMMM YYYY H:mm`,LLLL:`dddd D. MMMM YYYY H:mm`,l:`D. M. YYYY`},relativeTime:{future:`za %s`,past:`před %s`,s:i,m:i,mm:i,h:i,hh:i,d:i,dd:i,M:i,MM:i,y:i,yy:i}};return n.default.locale(a,null,!0),a}))}));export default n();