import{vt as e}from"./mui-BgU4WrXF.js";import{a as t,r as n,t as r}from"./Select-Bu2vmaew.js";import{r as i}from"./ReportFilter-CtusU-vs.js";import{Dt as a,pt as o}from"./index-bel1r0Sr.js";var s=e(),c=({columns:e,setColumns:c,columnsArray:l,rawValues:u,disabled:d})=>{let{classes:f}=i(),p=o();return(0,s.jsx)(`div`,{className:f.filterItem,children:(0,s.jsxs)(t,{fullWidth:!0,children:[(0,s.jsx)(n,{children:p(`sharedColumns`)}),(0,s.jsx)(r,{label:p(`sharedColumns`),value:e,onChange:e=>c(e.target.value),multiple:!0,disabled:d,children:l.map(([e,t])=>(0,s.jsx)(a,{value:e,children:u?t:p(t)},e))})]})})};export{c as t};