import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_id=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`id`,weekdays:`Minggu_Senin_Selasa_Rabu_Kamis_Jumat_Sabtu`.split(`_`),months:`Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_November_Desember`.split(`_`),weekdaysShort:`Min_Sen_Sel_Rab_Kam_Jum_Sab`.split(`_`),monthsShort:`Jan_Feb_Mar_Apr_Mei_Jun_Jul_Agt_Sep_Okt_Nov_Des`.split(`_`),weekdaysMin:`Mg_Sn_Sl_Rb_Km_Jm_Sb`.split(`_`),weekStart:1,formats:{LT:`HH.mm`,LTS:`HH.mm.ss`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY [pukul] HH.mm`,LLLL:`dddd, D MMMM YYYY [pukul] HH.mm`},relativeTime:{future:`dalam %s`,past:`%s yang lalu`,s:`beberapa detik`,m:`semenit`,mm:`%d menit`,h:`sejam`,hh:`%d jam`,d:`sehari`,dd:`%d hari`,M:`sebulan`,MM:`%d bulan`,y:`setahun`,yy:`%d tahun`},ordinal:function(e){return e+`.`}};return n.default.locale(r,null,!0),r}))}));export default n();