import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_lo=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`lo`,weekdays:`ອາທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ`.split(`_`),months:`ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ`.split(`_`),weekdaysShort:`ທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ`.split(`_`),monthsShort:`ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ`.split(`_`),weekdaysMin:`ທ_ຈ_ອຄ_ພ_ພຫ_ສກ_ສ`.split(`_`),ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`ວັນdddd D MMMM YYYY HH:mm`},relativeTime:{future:`ອີກ %s`,past:`%sຜ່ານມາ`,s:`ບໍ່ເທົ່າໃດວິນາທີ`,m:`1 ນາທີ`,mm:`%d ນາທີ`,h:`1 ຊົ່ວໂມງ`,hh:`%d ຊົ່ວໂມງ`,d:`1 ມື້`,dd:`%d ມື້`,M:`1 ເດືອນ`,MM:`%d ເດືອນ`,y:`1 ປີ`,yy:`%d ປີ`}};return n.default.locale(r,null,!0),r}))}));export default n();