import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_ka=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`ka`,weekdays:`კვირა_ორშაბათი_სამშაბათი_ოთხშაბათი_ხუთშაბათი_პარასკევი_შაბათი`.split(`_`),weekdaysShort:`კვი_ორშ_სამ_ოთხ_ხუთ_პარ_შაბ`.split(`_`),weekdaysMin:`კვ_ორ_სა_ოთ_ხუ_პა_შა`.split(`_`),months:`იანვარი_თებერვალი_მარტი_აპრილი_მაისი_ივნისი_ივლისი_აგვისტო_სექტემბერი_ოქტომბერი_ნოემბერი_დეკემბერი`.split(`_`),monthsShort:`იან_თებ_მარ_აპრ_მაი_ივნ_ივლ_აგვ_სექ_ოქტ_ნოე_დეკ`.split(`_`),weekStart:1,formats:{LT:`h:mm A`,LTS:`h:mm:ss A`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY h:mm A`,LLLL:`dddd, D MMMM YYYY h:mm A`},relativeTime:{future:`%s შემდეგ`,past:`%s წინ`,s:`წამი`,m:`წუთი`,mm:`%d წუთი`,h:`საათი`,hh:`%d საათის`,d:`დღეს`,dd:`%d დღის განმავლობაში`,M:`თვის`,MM:`%d თვის`,y:`წელი`,yy:`%d წლის`},ordinal:function(e){return e}};return n.default.locale(r,null,!0),r}))}));export default n();