import{vt as e}from"./mui-BgU4WrXF.js";import{u as t}from"./IconButton-oialqkv3.js";import{t as n}from"./Container-fY8-hTkD.js";import{i as r,n as i,r as a,t as o}from"./ExpandMore-D0ycvrdR.js";import{t as s}from"./Typography-7EcQ2i3p.js";import{n as c}from"./MenuItem-BNgF7Xqv.js";import{V as l,pt as u}from"./index-bel1r0Sr.js";import{n as d,t as f}from"./useSettingsStyles-Bugi6oTj.js";import{t as p}from"./LinkField-BMd_-lGk.js";var m=e(),h=()=>{let{classes:e}=f(),h=u(),{id:g}=t();return(0,m.jsx)(c,{menu:(0,m.jsx)(d,{}),breadcrumbs:[`settingsTitle`,`settingsUser`,`sharedConnections`],children:(0,m.jsx)(n,{maxWidth:`xs`,className:e.container,children:(0,m.jsxs)(r,{defaultExpanded:!0,children:[(0,m.jsx)(i,{expandIcon:(0,m.jsx)(o,{}),children:(0,m.jsx)(s,{variant:`subtitle1`,children:h(`sharedConnections`)})}),(0,m.jsxs)(a,{className:e.details,children:[(0,m.jsx)(p,{endpointAll:`/api/devices?all=true&excludeAttributes=true`,endpointLinked:`/api/devices?userId=${g}&excludeAttributes=true`,baseId:g,keyBase:`userId`,keyLink:`deviceId`,titleGetter:e=>`${e.name} (${e.uniqueId})`,label:h(`deviceTitle`)}),(0,m.jsx)(p,{endpointAll:`/api/groups?all=true`,endpointLinked:`/api/groups?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`groupId`,label:h(`settingsGroups`)}),(0,m.jsx)(p,{endpointAll:`/api/geofences?all=true`,endpointLinked:`/api/geofences?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`geofenceId`,label:h(`sharedGeofences`)}),(0,m.jsx)(p,{endpointAll:`/api/notifications?all=true`,endpointLinked:`/api/notifications?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`notificationId`,titleGetter:e=>l(h,e,!0),label:h(`sharedNotifications`)}),(0,m.jsx)(p,{endpointAll:`/api/calendars?all=true`,endpointLinked:`/api/calendars?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`calendarId`,label:h(`sharedCalendars`)}),(0,m.jsx)(p,{endpointAll:`/api/users?all=true&excludeAttributes=true`,endpointLinked:`/api/users?userId=${g}&excludeAttributes=true`,baseId:g,keyBase:`userId`,keyLink:`managedUserId`,label:h(`settingsUsers`)}),(0,m.jsx)(p,{endpointAll:`/api/attributes/computed?all=true`,endpointLinked:`/api/attributes/computed?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`attributeId`,titleGetter:e=>e.description,label:h(`sharedComputedAttributes`)}),(0,m.jsx)(p,{endpointAll:`/api/drivers?all=true`,endpointLinked:`/api/drivers?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`driverId`,titleGetter:e=>`${e.name} (${e.uniqueId})`,label:h(`sharedDrivers`)}),(0,m.jsx)(p,{endpointAll:`/api/commands?all=true`,endpointLinked:`/api/commands?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`commandId`,titleGetter:e=>e.description,label:h(`sharedSavedCommands`)}),(0,m.jsx)(p,{endpointAll:`/api/maintenance?all=true`,endpointLinked:`/api/maintenance?userId=${g}`,baseId:g,keyBase:`userId`,keyLink:`maintenanceId`,label:h(`sharedMaintenance`)})]})]})})})};export{h as default};