import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_fa=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`fa`,weekdays:`یک‌شنبه_دوشنبه_سه‌شنبه_چهارشنبه_پنج‌شنبه_جمعه_شنبه`.split(`_`),weekdaysShort:`یک‌شنبه_دوشنبه_سه‌شنبه_چهارشنبه_پنج‌شنبه_جمعه_شنبه`.split(`_`),weekdaysMin:`ی_د_س_چ_پ_ج_ش`.split(`_`),weekStart:6,months:`ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر`.split(`_`),monthsShort:`ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر`.split(`_`),ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`dddd, D MMMM YYYY HH:mm`},relativeTime:{future:`در %s`,past:`%s پیش`,s:`چند ثانیه`,m:`یک دقیقه`,mm:`%d دقیقه`,h:`یک ساعت`,hh:`%d ساعت`,d:`یک روز`,dd:`%d روز`,M:`یک ماه`,MM:`%d ماه`,y:`یک سال`,yy:`%d سال`}};return n.default.locale(r,null,!0),r}))}));export default n();