import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_el=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`el`,weekdays:`Κυριακή_Δευτέρα_Τρίτη_Τετάρτη_Πέμπτη_Παρασκευή_Σάββατο`.split(`_`),weekdaysShort:`Κυρ_Δευ_Τρι_Τετ_Πεμ_Παρ_Σαβ`.split(`_`),weekdaysMin:`Κυ_Δε_Τρ_Τε_Πε_Πα_Σα`.split(`_`),months:`Ιανουάριος_Φεβρουάριος_Μάρτιος_Απρίλιος_Μάιος_Ιούνιος_Ιούλιος_Αύγουστος_Σεπτέμβριος_Οκτώβριος_Νοέμβριος_Δεκέμβριος`.split(`_`),monthsShort:`Ιαν_Φεβ_Μαρ_Απρ_Μαι_Ιουν_Ιουλ_Αυγ_Σεπτ_Οκτ_Νοε_Δεκ`.split(`_`),ordinal:function(e){return e},weekStart:1,relativeTime:{future:`σε %s`,past:`πριν %s`,s:`μερικά δευτερόλεπτα`,m:`ένα λεπτό`,mm:`%d λεπτά`,h:`μία ώρα`,hh:`%d ώρες`,d:`μία μέρα`,dd:`%d μέρες`,M:`ένα μήνα`,MM:`%d μήνες`,y:`ένα χρόνο`,yy:`%d χρόνια`},formats:{LT:`h:mm A`,LTS:`h:mm:ss A`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY h:mm A`,LLLL:`dddd, D MMMM YYYY h:mm A`}};return n.default.locale(r,null,!0),r}))}));export default n();