import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_km=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`km`,weekdays:`អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍`.split(`_`),months:`មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ`.split(`_`),weekStart:1,weekdaysShort:`អា_ច_អ_ព_ព្រ_សុ_ស`.split(`_`),monthsShort:`មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ`.split(`_`),weekdaysMin:`អា_ច_អ_ព_ព្រ_សុ_ស`.split(`_`),ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD/MM/YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`dddd, D MMMM YYYY HH:mm`},relativeTime:{future:`%sទៀត`,past:`%sមុន`,s:`ប៉ុន្មានវិនាទី`,m:`មួយនាទី`,mm:`%d នាទី`,h:`មួយម៉ោង`,hh:`%d ម៉ោង`,d:`មួយថ្ងៃ`,dd:`%d ថ្ងៃ`,M:`មួយខែ`,MM:`%d ខែ`,y:`មួយឆ្នាំ`,yy:`%d ឆ្នាំ`},meridiem:function(e){return e>12?`ល្ងាច`:`ព្រឹក`}};return n.default.locale(r,null,!0),r}))}));export default n();