import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_lt=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r=`sausio_vasario_kovo_balandžio_gegužės_birželio_liepos_rugpjūčio_rugsėjo_spalio_lapkričio_gruodžio`.split(`_`),i=`sausis_vasaris_kovas_balandis_gegužė_birželis_liepa_rugpjūtis_rugsėjis_spalis_lapkritis_gruodis`.split(`_`),a=/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?|MMMM?(\[[^\[\]]*\]|\s)+D[oD]?/,o=function(e,t){return a.test(t)?r[e.month()]:i[e.month()]};o.s=i,o.f=r;var s={name:`lt`,weekdays:`sekmadienis_pirmadienis_antradienis_trečiadienis_ketvirtadienis_penktadienis_šeštadienis`.split(`_`),weekdaysShort:`sek_pir_ant_tre_ket_pen_šeš`.split(`_`),weekdaysMin:`s_p_a_t_k_pn_š`.split(`_`),months:o,monthsShort:`sau_vas_kov_bal_geg_bir_lie_rgp_rgs_spa_lap_grd`.split(`_`),ordinal:function(e){return e+`.`},weekStart:1,relativeTime:{future:`už %s`,past:`prieš %s`,s:`kelias sekundes`,m:`minutę`,mm:`%d minutes`,h:`valandą`,hh:`%d valandas`,d:`dieną`,dd:`%d dienas`,M:`mėnesį`,MM:`%d mėnesius`,y:`metus`,yy:`%d metus`},format:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`YYYY-MM-DD`,LL:`YYYY [m.] MMMM D [d.]`,LLL:`YYYY [m.] MMMM D [d.], HH:mm [val.]`,LLLL:`YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]`,l:`YYYY-MM-DD`,ll:`YYYY [m.] MMMM D [d.]`,lll:`YYYY [m.] MMMM D [d.], HH:mm [val.]`,llll:`YYYY [m.] MMMM D [d.], ddd, HH:mm [val.]`},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`YYYY-MM-DD`,LL:`YYYY [m.] MMMM D [d.]`,LLL:`YYYY [m.] MMMM D [d.], HH:mm [val.]`,LLLL:`YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]`,l:`YYYY-MM-DD`,ll:`YYYY [m.] MMMM D [d.]`,lll:`YYYY [m.] MMMM D [d.], HH:mm [val.]`,llll:`YYYY [m.] MMMM D [d.], ddd, HH:mm [val.]`}};return n.default.locale(s,null,!0),s}))}));export default n();