import{i as e}from"./chunk-aKtaBQYM.js";import{Ft as t,H as n,R as r,Y as i,ot as a,vt as o,z as s}from"./mui-BgU4WrXF.js";import{Lt as c}from"./index-bel1r0Sr.js";var l=e(t(),1),u=o(),d=e=>{let{absolute:t,children:n,classes:r,flexItem:a,orientation:o,textAlign:s,variant:l}=e;return i({root:[`root`,t&&`absolute`,l,o===`vertical`&&`vertical`,a&&`flexItem`,n&&`withChildren`,s===`right`&&o!==`vertical`&&`textAlignRight`,s===`left`&&o!==`vertical`&&`textAlignLeft`],wrapper:[`wrapper`,o===`vertical`&&`wrapperVertical`]},c,r)},f=n(`div`,{name:`MuiDivider`,slot:`Root`,overridesResolver:(e,t)=>{let{ownerState:n}=e;return[t.root,n.absolute&&t.absolute,t[n.variant],n.orientation===`vertical`&&t.vertical,n.flexItem&&t.flexItem,n.children&&t.withChildren,n.textAlign===`right`&&n.orientation!==`vertical`&&t.textAlignRight,n.textAlign===`left`&&n.orientation!==`vertical`&&t.textAlignLeft]}})(s(({theme:e})=>({margin:0,flexShrink:0,borderWidth:0,borderStyle:`solid`,borderColor:(e.vars||e).palette.divider,borderBottomWidth:`thin`,variants:[{props:{absolute:!0},style:{position:`absolute`,bottom:0,left:0,width:`100%`}},{props:{variant:`inset`},style:{marginLeft:72}},{props:{variant:`middle`,orientation:`horizontal`},style:{marginLeft:e.spacing(2),marginRight:e.spacing(2)}},{props:{variant:`middle`,orientation:`vertical`},style:{marginTop:e.spacing(1),marginBottom:e.spacing(1)}},{props:{orientation:`vertical`},style:{height:`100%`,borderBottomWidth:0,borderRightWidth:`thin`}},{props:{flexItem:!0},style:{alignSelf:`stretch`,height:`auto`}},{props:({ownerState:e})=>!!e.children,style:{display:`flex`,textAlign:`center`,border:0,borderTopStyle:`solid`,borderLeftStyle:`solid`,"&::before, &::after":{content:`""`,alignSelf:`center`}}},{props:({ownerState:e})=>e.children&&e.orientation!==`vertical`,style:{"&::before, &::after":{width:`100%`,borderTop:`thin solid ${(e.vars||e).palette.divider}`,borderTopStyle:`inherit`}}},{props:({ownerState:e})=>e.orientation===`vertical`&&e.children,style:{flexDirection:`column`,"&::before, &::after":{height:`100%`,borderLeft:`thin solid ${(e.vars||e).palette.divider}`,borderLeftStyle:`inherit`}}},{props:({ownerState:e})=>e.textAlign===`right`&&e.orientation!==`vertical`,style:{"&::before":{width:`90%`},"&::after":{width:`10%`}}},{props:({ownerState:e})=>e.textAlign===`left`&&e.orientation!==`vertical`,style:{"&::before":{width:`10%`},"&::after":{width:`90%`}}}]}))),p=n(`span`,{name:`MuiDivider`,slot:`Wrapper`,overridesResolver:(e,t)=>{let{ownerState:n}=e;return[t.wrapper,n.orientation===`vertical`&&t.wrapperVertical]}})(s(({theme:e})=>({display:`inline-block`,paddingLeft:`calc(${e.spacing(1)} * 1.2)`,paddingRight:`calc(${e.spacing(1)} * 1.2)`,whiteSpace:`nowrap`,variants:[{props:{orientation:`vertical`},style:{paddingTop:`calc(${e.spacing(1)} * 1.2)`,paddingBottom:`calc(${e.spacing(1)} * 1.2)`}}]}))),m=l.forwardRef(function(e,t){let n=r({props:e,name:`MuiDivider`}),{absolute:i=!1,children:o,className:s,orientation:c=`horizontal`,component:l=o||c===`vertical`?`div`:`hr`,flexItem:m=!1,role:h=l===`hr`?void 0:`separator`,textAlign:g=`center`,variant:_=`fullWidth`,...v}=n,y={...n,absolute:i,component:l,flexItem:m,orientation:c,role:h,textAlign:g,variant:_},b=d(y);return(0,u.jsx)(f,{as:l,className:a(b.root,s),role:h,ref:t,ownerState:y,"aria-orientation":h===`separator`&&(l!==`hr`||c===`vertical`)?c:void 0,...v,children:o?(0,u.jsx)(p,{className:b.wrapper,ownerState:y,children:o}):null})});export{m as t};