import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_hr=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r=`siječnja_veljače_ožujka_travnja_svibnja_lipnja_srpnja_kolovoza_rujna_listopada_studenoga_prosinca`.split(`_`),i=`siječanj_veljača_ožujak_travanj_svibanj_lipanj_srpanj_kolovoz_rujan_listopad_studeni_prosinac`.split(`_`),a=/D[oD]?(\[[^[\]]*\]|\s)+MMMM?/,o=function(e,t){return a.test(t)?r[e.month()]:i[e.month()]};o.s=i,o.f=r;var s={name:`hr`,weekdays:`nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota`.split(`_`),weekdaysShort:`ned._pon._uto._sri._čet._pet._sub.`.split(`_`),weekdaysMin:`ne_po_ut_sr_če_pe_su`.split(`_`),months:o,monthsShort:`sij._velj._ožu._tra._svi._lip._srp._kol._ruj._lis._stu._pro.`.split(`_`),weekStart:1,formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD.MM.YYYY`,LL:`D. MMMM YYYY`,LLL:`D. MMMM YYYY H:mm`,LLLL:`dddd, D. MMMM YYYY H:mm`},relativeTime:{future:`za %s`,past:`prije %s`,s:`sekunda`,m:`minuta`,mm:`%d minuta`,h:`sat`,hh:`%d sati`,d:`dan`,dd:`%d dana`,M:`mjesec`,MM:`%d mjeseci`,y:`godina`,yy:`%d godine`},ordinal:function(e){return e+`.`}};return n.default.locale(s,null,!0),s}))}));export default n();