import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_bg=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`bg`,weekdays:`неделя_понеделник_вторник_сряда_четвъртък_петък_събота`.split(`_`),weekdaysShort:`нед_пон_вто_сря_чет_пет_съб`.split(`_`),weekdaysMin:`нд_пн_вт_ср_чт_пт_сб`.split(`_`),months:`януари_февруари_март_април_май_юни_юли_август_септември_октомври_ноември_декември`.split(`_`),monthsShort:`яну_фев_мар_апр_май_юни_юли_авг_сеп_окт_ное_дек`.split(`_`),weekStart:1,ordinal:function(e){var t=e%100;if(t>10&&t<20)return e+`-ти`;var n=e%10;return n===1?e+`-ви`:n===2?e+`-ри`:n===7||n===8?e+`-ми`:e+`-ти`},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`D.MM.YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY H:mm`,LLLL:`dddd, D MMMM YYYY H:mm`},relativeTime:{future:`след %s`,past:`преди %s`,s:`няколко секунди`,m:`минута`,mm:`%d минути`,h:`час`,hh:`%d часа`,d:`ден`,dd:`%d дена`,M:`месец`,MM:`%d месеца`,y:`година`,yy:`%d години`}};return n.default.locale(r,null,!0),r}))}));export default n();