import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_si=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`si`,weekdays:`ඉරිදා_සඳුදා_අඟහරුවාදා_බදාදා_බ්‍රහස්පතින්දා_සිකුරාදා_සෙනසුරාදා`.split(`_`),months:`දුරුතු_නවම්_මැදින්_බක්_වෙසක්_පොසොන්_ඇසළ_නිකිණි_බිනර_වප්_ඉල්_උඳුවප්`.split(`_`),weekdaysShort:`ඉරි_සඳු_අඟ_බදා_බ්‍රහ_සිකු_සෙන`.split(`_`),monthsShort:`දුරු_නව_මැදි_බක්_වෙස_පොසො_ඇස_නිකි_බින_වප්_ඉල්_උඳු`.split(`_`),weekdaysMin:`ඉ_ස_අ_බ_බ්‍ර_සි_සෙ`.split(`_`),ordinal:function(e){return e},formats:{LT:`a h:mm`,LTS:`a h:mm:ss`,L:`YYYY/MM/DD`,LL:`YYYY MMMM D`,LLL:`YYYY MMMM D, a h:mm`,LLLL:`YYYY MMMM D [වැනි] dddd, a h:mm:ss`},relativeTime:{future:`%sකින්`,past:`%sකට පෙර`,s:`තත්පර කිහිපය`,m:`විනාඩිය`,mm:`විනාඩි %d`,h:`පැය`,hh:`පැය %d`,d:`දිනය`,dd:`දින %d`,M:`මාසය`,MM:`මාස %d`,y:`වසර`,yy:`වසර %d`}};return n.default.locale(r,null,!0),r}))}));export default n();