import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_tr=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`tr`,weekdays:`Pazar_Pazartesi_Salı_Çarşamba_Perşembe_Cuma_Cumartesi`.split(`_`),weekdaysShort:`Paz_Pts_Sal_Çar_Per_Cum_Cts`.split(`_`),weekdaysMin:`Pz_Pt_Sa_Ça_Pe_Cu_Ct`.split(`_`),months:`Ocak_Şubat_Mart_Nisan_Mayıs_Haziran_Temmuz_Ağustos_Eylül_Ekim_Kasım_Aralık`.split(`_`),monthsShort:`Oca_Şub_Mar_Nis_May_Haz_Tem_Ağu_Eyl_Eki_Kas_Ara`.split(`_`),weekStart:1,formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`DD.MM.YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY HH:mm`,LLLL:`dddd, D MMMM YYYY HH:mm`},relativeTime:{future:`%s sonra`,past:`%s önce`,s:`birkaç saniye`,m:`bir dakika`,mm:`%d dakika`,h:`bir saat`,hh:`%d saat`,d:`bir gün`,dd:`%d gün`,M:`bir ay`,MM:`%d ay`,y:`bir yıl`,yy:`%d yıl`},ordinal:function(e){return e+`.`}};return n.default.locale(r,null,!0),r}))}));export default n();