import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_mk=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`mk`,weekdays:`недела_понеделник_вторник_среда_четврток_петок_сабота`.split(`_`),months:`јануари_февруари_март_април_мај_јуни_јули_август_септември_октомври_ноември_декември`.split(`_`),weekStart:1,weekdaysShort:`нед_пон_вто_сре_чет_пет_саб`.split(`_`),monthsShort:`јан_фев_мар_апр_мај_јун_јул_авг_сеп_окт_ное_дек`.split(`_`),weekdaysMin:`нe_пo_вт_ср_че_пе_сa`.split(`_`),ordinal:function(e){return e},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`D.MM.YYYY`,LL:`D MMMM YYYY`,LLL:`D MMMM YYYY H:mm`,LLLL:`dddd, D MMMM YYYY H:mm`},relativeTime:{future:`после %s`,past:`пред %s`,s:`неколку секунди`,m:`минута`,mm:`%d минути`,h:`час`,hh:`%d часа`,d:`ден`,dd:`%d дена`,M:`месец`,MM:`%d месеци`,y:`година`,yy:`%d години`}};return n.default.locale(r,null,!0),r}))}));export default n();