import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_mn=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e),r={name:`mn`,weekdays:`Ням_Даваа_Мягмар_Лхагва_Пүрэв_Баасан_Бямба`.split(`_`),months:`Нэгдүгээр сар_Хоёрдугаар сар_Гуравдугаар сар_Дөрөвдүгээр сар_Тавдугаар сар_Зургадугаар сар_Долдугаар сар_Наймдугаар сар_Есдүгээр сар_Аравдугаар сар_Арван нэгдүгээр сар_Арван хоёрдугаар сар`.split(`_`),weekdaysShort:`Ням_Дав_Мяг_Лха_Пүр_Баа_Бям`.split(`_`),monthsShort:`1 сар_2 сар_3 сар_4 сар_5 сар_6 сар_7 сар_8 сар_9 сар_10 сар_11 сар_12 сар`.split(`_`),weekdaysMin:`Ня_Да_Мя_Лх_Пү_Ба_Бя`.split(`_`),ordinal:function(e){return e},formats:{LT:`HH:mm`,LTS:`HH:mm:ss`,L:`YYYY-MM-DD`,LL:`YYYY оны MMMMын D`,LLL:`YYYY оны MMMMын D HH:mm`,LLLL:`dddd, YYYY оны MMMMын D HH:mm`},relativeTime:{future:`%s`,past:`%s`,s:`саяхан`,m:`м`,mm:`%dм`,h:`1ц`,hh:`%dц`,d:`1ө`,dd:`%dө`,M:`1с`,MM:`%dс`,y:`1ж`,yy:`%dж`}};return n.default.locale(r,null,!0),r}))}));export default n();