import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_fi=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e);function r(e,t,n,r){var i={s:`muutama sekunti`,m:`minuutti`,mm:`%d minuuttia`,h:`tunti`,hh:`%d tuntia`,d:`päivä`,dd:`%d päivää`,M:`kuukausi`,MM:`%d kuukautta`,y:`vuosi`,yy:`%d vuotta`,numbers:`nolla_yksi_kaksi_kolme_neljä_viisi_kuusi_seitsemän_kahdeksan_yhdeksän`.split(`_`)},a={s:`muutaman sekunnin`,m:`minuutin`,mm:`%d minuutin`,h:`tunnin`,hh:`%d tunnin`,d:`päivän`,dd:`%d päivän`,M:`kuukauden`,MM:`%d kuukauden`,y:`vuoden`,yy:`%d vuoden`,numbers:`nollan_yhden_kahden_kolmen_neljän_viiden_kuuden_seitsemän_kahdeksan_yhdeksän`.split(`_`)},o=r&&!t?a:i,s=o[n];return e<10?s.replace(`%d`,o.numbers[e]):s.replace(`%d`,e)}var i={name:`fi`,weekdays:`sunnuntai_maanantai_tiistai_keskiviikko_torstai_perjantai_lauantai`.split(`_`),weekdaysShort:`su_ma_ti_ke_to_pe_la`.split(`_`),weekdaysMin:`su_ma_ti_ke_to_pe_la`.split(`_`),months:`tammikuu_helmikuu_maaliskuu_huhtikuu_toukokuu_kesäkuu_heinäkuu_elokuu_syyskuu_lokakuu_marraskuu_joulukuu`.split(`_`),monthsShort:`tammi_helmi_maalis_huhti_touko_kesä_heinä_elo_syys_loka_marras_joulu`.split(`_`),ordinal:function(e){return e+`.`},weekStart:1,yearStart:4,relativeTime:{future:`%s päästä`,past:`%s sitten`,s:r,m:r,mm:r,h:r,hh:r,d:r,dd:r,M:r,MM:r,y:r,yy:r},formats:{LT:`HH.mm`,LTS:`HH.mm.ss`,L:`DD.MM.YYYY`,LL:`D. MMMM[ta] YYYY`,LLL:`D. MMMM[ta] YYYY, [klo] HH.mm`,LLLL:`dddd, D. MMMM[ta] YYYY, [klo] HH.mm`,l:`D.M.YYYY`,ll:`D. MMM YYYY`,lll:`D. MMM YYYY, [klo] HH.mm`,llll:`ddd, D. MMM YYYY, [klo] HH.mm`}};return n.default.locale(i,null,!0),i}))}));export default n();