import{t as e}from"./chunk-aKtaBQYM.js";import{t}from"./dayjs.min-C4hTNXA3.js";var n=e(((e,n)=>{(function(r,i){typeof e==`object`&&n!==void 0?n.exports=i(t()):typeof define==`function`&&define.amd?define([`dayjs`],i):(r=typeof globalThis<`u`?globalThis:r||self).dayjs_locale_sl=i(r.dayjs)})(e,(function(e){function t(e){return e&&typeof e==`object`&&`default`in e?e:{default:e}}var n=t(e);function r(e){return e%100==2}function i(e){return e%100==3||e%100==4}function a(e,t,n,a){var o=e+` `;switch(n){case`s`:return t||a?`nekaj sekund`:`nekaj sekundami`;case`m`:return t?`ena minuta`:`eno minuto`;case`mm`:return r(e)?o+(t||a?`minuti`:`minutama`):i(e)?o+(t||a?`minute`:`minutami`):o+(t||a?`minut`:`minutami`);case`h`:return t?`ena ura`:`eno uro`;case`hh`:return r(e)?o+(t||a?`uri`:`urama`):i(e)?o+(t||a?`ure`:`urami`):o+(t||a?`ur`:`urami`);case`d`:return t||a?`en dan`:`enim dnem`;case`dd`:return r(e)?o+(t||a?`dneva`:`dnevoma`):o+(t||a?`dni`:`dnevi`);case`M`:return t||a?`en mesec`:`enim mesecem`;case`MM`:return r(e)?o+(t||a?`meseca`:`mesecema`):i(e)?o+(t||a?`mesece`:`meseci`):o+(t||a?`mesecev`:`meseci`);case`y`:return t||a?`eno leto`:`enim letom`;case`yy`:return r(e)?o+(t||a?`leti`:`letoma`):i(e)?o+(t||a?`leta`:`leti`):o+(t||a?`let`:`leti`)}}var o={name:`sl`,weekdays:`nedelja_ponedeljek_torek_sreda_četrtek_petek_sobota`.split(`_`),months:`januar_februar_marec_april_maj_junij_julij_avgust_september_oktober_november_december`.split(`_`),weekStart:1,weekdaysShort:`ned._pon._tor._sre._čet._pet._sob.`.split(`_`),monthsShort:`jan._feb._mar._apr._maj._jun._jul._avg._sep._okt._nov._dec.`.split(`_`),weekdaysMin:`ne_po_to_sr_če_pe_so`.split(`_`),ordinal:function(e){return e+`.`},formats:{LT:`H:mm`,LTS:`H:mm:ss`,L:`DD.MM.YYYY`,LL:`D. MMMM YYYY`,LLL:`D. MMMM YYYY H:mm`,LLLL:`dddd, D. MMMM YYYY H:mm`,l:`D. M. YYYY`},relativeTime:{future:`čez %s`,past:`pred %s`,s:a,m:a,mm:a,h:a,hh:a,d:a,dd:a,M:a,MM:a,y:a,yy:a}};return n.default.locale(o,null,!0),o}))}));export default n();